@@ -372,7 +372,7 @@ class BaseNewsletter(models.Model):
 
 
     def can_edit_newsletter(self, user):
-        return user.has_perm('coop_cms.change_newsletter')
+        return user.has_perm('coop.mailing.change_newsletter')
 
     def get_absolute_url(self):
         return reverse('coop_view_newsletter', args=[self.id])
