@@ -11,11 +11,10 @@ from django.contrib import messages
 from django.contrib.auth.decorators import login_required
 from django.conf import settings
 from colorbox.decorators import popup_redirect
-from coop_local.models import NewsletterSending, MailingList
+from coop_local.models import Newsletter, NewsletterSending, MailingList
 from coop.mailing.utils import send_newsletter
 from django.utils.log import getLogger
 from datetime import datetime
-from coop_local.models import Newsletter
 from coop.mailing import forms
 from django.core.urlresolvers import reverse
 from django.contrib.sites.models import Site
@@ -133,6 +132,8 @@ def new_newsletter(request, newsletter_id=None):
     else:
         newsletter = None
 
+    print Newsletter
+
     try:
         if request.method == "POST":
             form = forms.NewNewsletterForm(request.user, request.POST, instance=newsletter)
@@ -144,7 +145,7 @@ def new_newsletter(request, newsletter_id=None):
             form = forms.NewNewsletterForm(request.user, instance=newsletter)
 
         return render_to_response(
-            'coop_cms/popup_new_newsletter.html',
+            'mailing/popup_new_newsletter.html',
             locals(),
             context_instance=RequestContext(request)
         )
@@ -185,7 +186,7 @@ def change_newsletter_template(request, newsletter_id):
         form = forms.NewsletterTemplateForm(newsletter, request.user)
 
     return render_to_response(
-        'coop_cms/popup_change_newsletter_template.html',
+        'mailing/popup_change_newsletter_template.html',
         {'form': form, 'newsletter': newsletter},
         context_instance=RequestContext(request)
     )
@@ -221,7 +222,7 @@ def test_newsletter(request, newsletter_id):
             return HttpResponseRedirect(newsletter.get_edit_url())
 
     return render_to_response(
-        'coop_cms/popup_test_newsletter.html',
+        'mailing/popup_test_newsletter.html',
         {'newsletter': newsletter, 'dests': dests},
         context_instance=RequestContext(request)
     )
@@ -242,7 +243,7 @@ def schedule_newsletter_sending(request, newsletter_id):
         form = forms.NewsletterSchedulingForm(instance=instance, initial={'scheduling_dt': datetime.now()})
 
     return render_to_response(
-        'coop_cms/popup_schedule_newsletter_sending.html',
+        'mailing/popup_schedule_newsletter_sending.html',
         {'newsletter': newsletter, 'form': form},
         context_instance=RequestContext(request)
     )
