@@ -13,7 +13,7 @@ from django.db.models import Q
 from django.contrib.admin.widgets import AdminURLFieldWidget
 from django.db.models import URLField
 from django.utils.safestring import mark_safe
-
+from django.contrib.contenttypes.generic import GenericTabularInline
 from sorl.thumbnail.admin import AdminImageMixin
 from tinymce.widgets import AdminTinyMCE
 from coop.agenda.admin import DatedInline
@@ -26,10 +26,7 @@ if "coop.exchange" in settings.INSTALLED_APPS:
 if "coop_geo" in settings.INSTALLED_APPS:
     from coop_geo.admin import LocatedInline, AreaInline
 
-if 'coop.mailing' in settings.INSTALLED_APPS:
-    from coop.mailing.admin import SubscribtionMailingListInline
 
-from django.contrib.contenttypes.generic import GenericTabularInline
 
 
 class URLFieldWidget(AdminURLFieldWidget):
@@ -127,7 +124,7 @@ def create_action(category):
 class OrganizationAdmin(AdminImageMixin, FkAutocompleteAdmin):
     change_form_template = 'admintools_bootstrap/tabbed_change_form.html'
     form = OrganizationAdminForm
-    list_display = ['logo_list_display', 'label', 'active', 'has_description', 'has_location']
+    list_display = ['logo_list_display', 'label', 'active', 'has_location']#'has_description',
     list_display_links = ['label', ]
     search_fields = ['title', 'acronym', 'subtitle', 'acronym', 'description']
     list_filter = ['active', 'category']
@@ -156,8 +153,6 @@ class OrganizationAdmin(AdminImageMixin, FkAutocompleteAdmin):
                     EngagementInline,
                     LocatedInline,
                     ]
-    if "coop.mailing" in settings.INSTALLED_APPS:
-        inlines.append(SubscribtionMailingListInline)
 
     # grace au patch
     # https://code.djangoproject.com/ticket/17856
