@@ -25,13 +25,3 @@ from coop.default_project_urls import urlpatterns as default_project_urls
 urlpatterns += default_project_urls
 
 
-if 'haystack' in settings.INSTALLED_APPS:
-    # minimal version
-    from haystack.views import search_view_factory, SearchView
-    urlpatterns += patterns('haystack.views',
-        url(r'^search/$', search_view_factory(
-            view_class=SearchView,
-            template='search/search.html',
-            load_all=False
-        ), name='haystack_search'),
-    )
